<?php

namespace App\Admin\Forms;


use App\Command\Log;

use App\Models\Company;
use App\Models\Employee;
use App\Models\Income;
use App\Models\Pay;
use Dcat\Admin\Widgets\Form;
use Dcat\Admin\Contracts\LazyRenderable;
use Dcat\Admin\Traits\LazyWidget;
use Illuminate\Support\Facades\DB;


class CheckIncome extends Form implements LazyRenderable
{
    use LazyWidget;

    /**
     * Handle the form request.
     *
     * @param array $input
     *
     * @return mixed
     */
    public function handle(array $input)
    {
        DB::beginTransaction();
        $income = Income::find($this->payload['id']);
        if ($income->batch_id) {
            return $this->response()->error('提现已受理，请等待。。。')->refresh();
        }
        try {
            $status = (int)$input['status']; //审核状态 0：审核中 1：通过 2：拒绝
            $income->remark = $input['remark'] ?? '';
            if ($status == 1) {
                $pay_res =  Pay::toBalance($income->openid, $income->amount, '用户提现');
                if (!empty($pay_res)) {
                    $income->partner_trade_no = $pay_res[0];
                    $income->out_batch_no = $pay_res[1];
                    $income->batch_id = $pay_res[2];
                    $income->batch_status = $pay_res[3];
                }
            } elseif ($status == 2) {
                $income->status = 2;
                //恢复陪诊员余额
                if ($income->user_type == 1) {
                    $em = Employee::find($income->ec_id);
                    $em->balance += $income->amount;
                    $em->freeze_balance -= $income->amount;
                    $em->save();
                } else if ($income->user_type == 2) {
                    $cm = Company::find($income->ec_id);
                    $cm->balance += $income->amount;
                    $cm->freeze_balance -= $income->amount;
                    $cm->save();
                }
            }

            $income->save();

            DB::commit();
            Log::add('提现已受理', $income->toArray());
        } catch (\Exception $exception) {
            DB::rollBack();

            Log::add('用户提现失败', $exception->getMessage());
            return $this->response()->error('用户提现失败')->refresh();
        }
        return $this->response()->success('用户提现已受理')->refresh();
    }

    public function handle_202312(array $input)
    {
        DB::beginTransaction();
        try {
            $income = Income::find($this->payload['id']);
            $income->status = $input['status'];
            $income->remark = $input['remark'] ?? '';
            if ($income->status == 1) {
                // $income->partner_trade_no = Pay::toBalance($income->openid,$income->amount,'用户提现');
                $pay_res =  Pay::toBalance($income->openid, $income->amount, '用户提现');
                Log::add('用户提现-微信结果', $pay_res);
                if (!empty($pay_res)) {
                    $income->partner_trade_no = $pay_res[0];
                    $income->out_batch_no = $pay_res[1];
                    $income->batch_id = $pay_res[2];
                } else { //提现失败
                    $income->status = 2;
                }
            }

            $income->save();
            if ($income->user_type == 1) {
                $em = Employee::find($income->ec_id);
                if ($income->status == 2) {
                    $em->balance += $income->amount;
                }
                $em->freeze_balance -= $income->amount;;
                $em->save();
            } else if ($income->user_type == 2) {
                $cm = Company::find($income->ec_id);
                if ($income->status == 2) {
                    $cm->balance += $income->amount;
                }
                $cm->freeze_balance -= $income->amount;
                $cm->save();
            }
            DB::commit();
            Log::add('用户提现成功', $income->toArray());
        } catch (\Exception $exception) {
            DB::rollBack();
            Log::add('用户提现失败', $exception);
            return $this->response()->error('用户提现失败')->refresh();
        }
        return $this->response()->success('用户提现成功')->refresh();
    }

    /**
     * Build a form here.
     */
    public function form()
    {
        $this->radio('status', '提现审核')->options([1 => '同意提现', 2 => '拒绝提现'])
            ->when(2, function (Form $form) {
                $form->textarea('remark', '拒绝理由');
            })
            ->required();
    }

    /**
     * The data of the form.
     *
     * @return array
     */
    public function default()
    {
        // 获取外部传递参数
        return [];
    }
}
